@@ -339,6 +339,8 @@ class KempBaseObjectModel(object):
     _API_IGNORE = (
         "ip_address",
         "endpoint",
+        "rsindex",
+        "vsindex",
     )
 
     def __repr__(self):
@@ -522,6 +524,8 @@ class RealServer(HttpClient, KempBaseObjectModel):
         return send_response(response)
 
     def populate_real_server_attributes(self, rs_data):
+        self.rsindex = rs_data.get('RsIndex', None)
+        self.vsindex = rs_data.get('VSIndex', None)
         self.status = rs_data.get('Status', None)
         self.forward = rs_data.get('Forward', None)
         self.enable = rs_data.get('Enable', None)
